import * as Main from 'resource:///org/gnome/shell/ui/main.js';
import { Extension, gettext as _, } from 'resource:///org/gnome/shell/extensions/extension.js';
import GnomeBluetooth from 'gi://GnomeBluetooth';
import NoiseclapperIndicator from './indicator.js';
import { LogType, logIfEnabled, devicesObjectToArray, sendSignal, supportedDeviceNames, updateLogging, } from './common.js';
export default class NoiseclapperExtension extends Extension {
    settings = this.getSettings();
    bluetoothClient;
    indicator;
    settingsHandler;
    enable() {
        logIfEnabled(LogType.Info, 'Enabling Noiseclapper...');
        logIfEnabled(LogType.Debug, 'Enabling Bluetooth client...');
        this.bluetoothClient = new GnomeBluetooth.Client();
        logIfEnabled(LogType.Debug, 'Creating and adding Noiseclapper indicator...');
        this.indicator = new NoiseclapperIndicator(this);
        Main.panel.addToStatusArea(this.uuid, this.indicator);
        this.settingsHandler = this.settings.connect('changed', this.applySettings.bind(this));
        this.applySettings();
        logIfEnabled(LogType.Info, 'Startup successful.');
    }
    disable() {
        logIfEnabled(LogType.Info, 'Disabling Noiseclapper...');
        this.bluetoothClient = undefined;
        logIfEnabled(LogType.Debug, 'Removing Noiseclapper indicator...');
        this.indicator?.destroy();
        this.indicator = undefined;
        if (this.settingsHandler !== undefined) {
            this.settings.disconnect(this.settingsHandler);
            this.settingsHandler = undefined;
        }
    }
    signalHandler(signal) {
        logIfEnabled(LogType.Debug, 'Preparing to send signal : [' + signal + ']');
        const devices = devicesObjectToArray(this.bluetoothClient.get_devices());
        let hasFoundAtLeastOneDevice = false;
        for (const device of devices) {
            if (device.connected && supportedDeviceNames.includes(device.name)) {
                hasFoundAtLeastOneDevice = true;
                const { name, address } = device;
                logIfEnabled(LogType.Info, `Sending signal [${signal}] to device [${name}] with MAC address [${address}]`);
                void sendSignal(signal, address);
            }
        }
        if (!hasFoundAtLeastOneDevice) {
            logIfEnabled(LogType.Error, 'No compatible devices found.');
            Main.notifyError('Noiseclapper - ' + _('Error'), _('No connected compatible devices found.'));
        }
    }
    applySettings() {
        logIfEnabled(LogType.Debug, 'Applying settings...');
        updateLogging(this.settings.get_boolean('logging-enabled'));
        this.indicator.applyPosition();
    }
}
